package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.marketing.xlk.service.ICurriculumService;
import com.yunzhi.marketing.xlk.entity.Curriculum;
import org.springframework.web.bind.annotation.RestController;
/**
 * <p>
    * 课程表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-05-18
 */
@RestController
@RequestMapping("/")
public class CurriculumController extends BaseController {

    private final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CurriculumController.class);

    @Autowired
    public ICurriculumService iCurriculumService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/curriculum",method= RequestMethod.GET)
    public ResponseBean curriculumList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<Curriculum> pg = new Page<>(pageNum, pageSize);
            com.baomidou.mybatisplus.core.conditions.query.QueryWrapper<Curriculum> queryWrapper = new com.baomidou.mybatisplus.core.conditions.query.QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<Curriculum> result = iCurriculumService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("curriculumList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param curriculum 实体对象
     * @return
     */
    @RequestMapping(value="/curriculum",method= RequestMethod.POST)
    public ResponseBean curriculumAdd(@RequestBody Curriculum curriculum){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iCurriculumService.save(curriculum)){
                responseBean.addSuccess(curriculum);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("curriculumAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/curriculum/{id}", method= RequestMethod.DELETE)
    public ResponseBean curriculumDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iCurriculumService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("curriculumDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param curriculum 实体对象
     * @return
     */
    @RequestMapping(value="/curriculum/{id}",method= RequestMethod.PUT)
    public ResponseBean curriculumUpdate(@PathVariable Integer id,
                                        @RequestBody Curriculum curriculum){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iCurriculumService.updateById(curriculum)){
                responseBean.addSuccess(curriculum);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("curriculumUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/curriculum/{id}",method= RequestMethod.GET)
    public ResponseBean curriculumGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iCurriculumService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("curriculumDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
