package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.xlk.entity.Video;
import com.yunzhi.marketing.xlk.service.IVideoService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 视频表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-05-18
 */
@RestController
@RequestMapping("/api")
public class VideoController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(VideoController.class);

    @Autowired
    public IVideoService iVideoService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/video",method= RequestMethod.GET)
    public ResponseBean videoList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                  @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<Video> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<Video> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<Video> result = iVideoService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("videoList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param video 实体对象
     * @return
     */
    @RequestMapping(value="/video",method= RequestMethod.POST)
    public ResponseBean videoAdd(@RequestBody Video video){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iVideoService.save(video)){
                responseBean.addSuccess(video);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("videoAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/video/{id}", method= RequestMethod.DELETE)
    public ResponseBean videoDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iVideoService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("videoDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param video 实体对象
     * @return
     */
    @RequestMapping(value="/video/{id}",method= RequestMethod.PUT)
    public ResponseBean videoUpdate(@PathVariable Integer id,
                                        @RequestBody Video video){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iVideoService.updateById(video)){
                responseBean.addSuccess(video);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("videoUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/video/{id}",method= RequestMethod.GET)
    public ResponseBean videoGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iVideoService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("videoDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
